@@ -657,7 +657,7 @@ int aa_change_hat(const char *hats[], int count, u64 token, bool permtest)
 			hat = aa_find_child(root, hats[i]);
 		if (!hat) {
 			if (!COMPLAIN_MODE(root) || permtest) {
-				if (list_empty_rcu(&root->base.profiles))
+				if (list_empty(&root->base.profiles))
 					error = -ECHILD;
 				else
 					error = -ENOENT;
